"""nitdms"""
from nitdms.reader import TdmsFile
from waveformDT.waveform import WaveformDT
from nitdms.version import __version__

__all__ = ["TdmsFile", "WaveformDT"]
